==> haskell-hls-explicit-record-fields-plugin-2.1.0.0-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-explicit-record-fields-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-explicit-record-fields-plugin
version:              2.1.0.0
visibility:           public
id:
    hls-explicit-record-fields-plugin-2.1.0.0-8fgWB6bXyhUCEC37WkJHRp

key:
    hls-explicit-record-fields-plugin-2.1.0.0-8fgWB6bXyhUCEC37WkJHRp

license:              BSD-3-Clause
maintainer:           berk.ozkutuk@tweag.io
author:               Berk Ozkutuk
synopsis:             Explicit record fields plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  50e974cfd17145388aa1bdff9b2652d5
exposed:              True
exposed-modules:      Ide.Plugin.ExplicitFields
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-record-fields-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-record-fields-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-record-fields-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-explicit-record-fields-plugin
hs-libraries:
    HShls-explicit-record-fields-plugin-2.1.0.0-8fgWB6bXyhUCEC37WkJHRp

depends:
    base-4.17.2.1 containers-0.6.7 ghc-boot-th-9.4.8
    ghcide-2.1.0.0-JBq8BlG0DEi1qEeHQWL9pq
    hls-graph-2.1.0.0-AJ9HUzP28sjIJuxYVHDDnX
    hls-plugin-api-2.1.0.0-8OzZBCSKxFIKibsC3x3Rbf
    lens-5.3-FNJYFG5nVy3K1UtPWTWg2x lsp-2.1.0.0-5voKI1DXTs5JAKa5U64Eo4
    syb-0.7.2.4-LBhYOmNvCTD9nmTNYbjxYb text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-Cw2Ec4BgC4sInKE4e5RLSk

haddock-interfaces:
    /usr/share/doc/haskell-hls-explicit-record-fields-plugin/html/hls-explicit-record-fields-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-explicit-record-fields-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-explicit-record-fields-plugin-2.1.0.0-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-explicit-record-fields-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-explicit-record-fields-plugin
version:              2.1.0.0
visibility:           public
id:
    hls-explicit-record-fields-plugin-2.1.0.0-GpSZhRRZaz93sIrc6f0aQx

key:
    hls-explicit-record-fields-plugin-2.1.0.0-GpSZhRRZaz93sIrc6f0aQx

license:              BSD-3-Clause
maintainer:           berk.ozkutuk@tweag.io
author:               Berk Ozkutuk
synopsis:             Explicit record fields plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  2d32aaa75d44f3bf8b3043cec6d8ca25
exposed:              True
exposed-modules:      Ide.Plugin.ExplicitFields
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-record-fields-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-record-fields-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-record-fields-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-explicit-record-fields-plugin
hs-libraries:
    HShls-explicit-record-fields-plugin-2.1.0.0-GpSZhRRZaz93sIrc6f0aQx

depends:
    base-4.17.2.1 containers-0.6.7 ghc-boot-th-9.4.8
    ghcide-2.1.0.0-Eba7IKOMlUg1JSq9BskH28
    hls-graph-2.1.0.0-AJ9HUzP28sjIJuxYVHDDnX
    hls-plugin-api-2.1.0.0-AS7TpGIV2D21ChjWdaeqTl
    lens-5.3.1-3FYsDpCHEKEBLMSbQ9nAqF
    lsp-2.1.0.0-DyFP5ixOoJMD0lbV6POXwv
    syb-0.7.2.4-LBhYOmNvCTD9nmTNYbjxYb text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-Cw2Ec4BgC4sInKE4e5RLSk

haddock-interfaces:
    /usr/share/doc/haskell-hls-explicit-record-fields-plugin/html/hls-explicit-record-fields-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-explicit-record-fields-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
